enum TableFilterType {
  Search,
  Select,
  Date,
}

// 选择框的选项
interface SelectFilterOptions {
  label: string
  value: any
}

// 筛选条件的基础信息
interface BaseFilterItem {
  type: TableFilterType
  name: string
  value: any
  placeholder: string
}

// 搜索框
interface SearchFilterItem extends BaseFilterItem {
  type: TableFilterType.Search
}

// 选择框
interface SelectFilterItem extends BaseFilterItem {
  type: TableFilterType.Select
  options: SelectFilterOptions[]
}

// 日期选择框
interface DateFilterItem extends BaseFilterItem {
  type: TableFilterType.Date
  startDate: Date
  endDate: Date
}

// 联合类型
type TableFilterItem = SearchFilterItem | SelectFilterItem | DateFilterItem

// 表格的props
interface TableProps {
  filtersInfo: {
    [key: string]: TableFilterItem
  }
}
export { TableFilterType }
export type {
  SelectFilterOptions,
  BaseFilterItem,
  SearchFilterItem,
  SelectFilterItem,
  DateFilterItem,
  TableFilterItem,
  TableProps,
}
